@@ -19,13 +19,16 @@ class NoCaptchaTask:
         :param sleeptime: Время ожидания решения
         :param kwargs: Необязательные параметры, можно переопределить userAgent
         """
+
+        if sleep_time < 5:
+            raise ValueError(f'Параметр `sleep_time` должен быть не менее 5. Вы передали - {sleep_time}')
         self.sleep_time = sleep_time
 
         # Пайлоад для создания задачи
         self.task_payload = {"clientKey": anticaptcha_key,
                              "task":
                                  {
-                                     "type": "FunCaptchaTask",
+                                     "type": "NoCaptchaTask",
                                      "userAgent": user_agent_data,
                                      "proxyType": proxyType,
                                      "proxyAddress": proxyAddress,
@@ -42,7 +45,7 @@ class NoCaptchaTask:
                 self.task_payload['task'].update({key: kwargs[key]})
 
     # Работа с капчей
-    def captcha_handler(self, websiteURL, websiteKey):
+    def captcha_handler(self, websiteURL, websiteKey, **kwargs):
         """
         Метод получает ссылку на страницу, где расположена капча, и ключ капчи
         :param: websiteURL: Ссылка на страницу с капчёй
@@ -52,7 +55,7 @@ class NoCaptchaTask:
         self.task_payload['task'].update({"websiteURL": websiteURL,
                                           "websiteKey": websiteKey})
         # отправляем реквест, в ответ получаем JSON содержащий номер решаемой капчи
-        captcha_id = requests.post(create_task_url, json=self.task_payload).json()
+        captcha_id = requests.post(create_task_url, json=self.task_payload, **kwargs).json()
 
         # Проверка статуса создания задачи, если создано без ошибок - извлекаем ID задачи, иначе возвращаем ответ сервера
         if captcha_id['errorId'] == 0:
@@ -95,7 +98,7 @@ class aioNoCaptchaTask:
         self.task_payload = {"clientKey": anticaptcha_key,
                              "task":
                                  {
-                                     "type": "FunCaptchaTask",
+                                     "type": "NoCaptchaTask",
                                      "userAgent": user_agent_data,
                                      "proxyType": proxyType,
                                      "proxyAddress": proxyAddress,
@@ -122,7 +125,6 @@ class aioNoCaptchaTask:
         self.task_payload["task"].update({"websiteURL": websiteURL,
                                           "websiteKey": websiteKey})
         # отправляем реквест, в ответ получаем JSON содержащий номер решаемой капчи
-        captcha_id = requests.post(create_task_url, json=self.task_payload).json()
         async with aiohttp.ClientSession() as session:
             async with session.post(create_task_url, json=self.task_payload) as resp:
                 captcha_id = await resp.json()
