@@ -14,7 +14,8 @@ class NoCaptchaTaskProxyless:
 		:param sleep_time: Время ожидания решения капчи
 		:param kwargs: Другие необязательные параметры из документации
 		"""
-		self.ANTICAPTCHA_KEY = anticaptcha_key
+		if sleep_time < 5:
+			raise ValueError(f'Параметр `sleep_time` должен быть не менее 5. Вы передали - {sleep_time}')
 		self.sleep_time = sleep_time
 		
 		# Пайлоад для создания задачи
@@ -27,7 +28,7 @@ class NoCaptchaTaskProxyless:
 		                     }
 		
 		# Пайлоад для получения результата
-		self.result_payload = {"clientKey": self.ANTICAPTCHA_KEY}
+		self.result_payload = {"clientKey": anticaptcha_key}
 		
 		# Если переданы ещё параметры - вносим их в payload
 		if kwargs:
@@ -35,7 +36,7 @@ class NoCaptchaTaskProxyless:
 				self.task_payload['task'].update({key: kwargs[key]})
 	
 	# Работа с капчёй
-	def captcha_handler(self, websiteURL, websiteKey):
+	def captcha_handler(self, websiteURL, websiteKey, **kwargs):
 		"""
 		Метод решения ReCaptcha
 		:param websiteURL: Ссылка на страницу с капчёй
@@ -48,7 +49,7 @@ class NoCaptchaTaskProxyless:
 		                                  "websiteKey": websiteKey})
 		# Отправляем на антикапчу пайлоад
 		# в результате получаем JSON ответ содержащий номер решаемой капчи
-		captcha_id = requests.post(create_task_url, json=self.task_payload).json()
+		captcha_id = requests.post(create_task_url, json=self.task_payload, **kwargs).json()
 		
 		# Проверка статуса создания задачи, если создано без ошибок - извлекаем ID задачи, иначе возвращаем ответ сервера
 		if captcha_id['errorId'] == 0:
@@ -84,7 +85,8 @@ class aioNoCaptchaTaskProxyless:
 		:param sleep_time: Время ожидания решения капчи
 		:param kwargs: Другие необязательные параметры из документации
 		"""
-		self.ANTICAPTCHA_KEY = anticaptcha_key
+		if sleep_time < 5:
+			raise ValueError(f'Параметр `sleep_time` должен быть не менее 5. Вы передали - {sleep_time}')
 		self.sleep_time = sleep_time
 		
 		# Пайлоад для создания задачи
@@ -97,7 +99,7 @@ class aioNoCaptchaTaskProxyless:
 		                     }
 		
 		# Пайлоад для получения результата
-		self.result_payload = {"clientKey": self.ANTICAPTCHA_KEY}
+		self.result_payload = {"clientKey": anticaptcha_key}
 		
 		# Если переданы ещё параметры - вносим их в payload
 		if kwargs:
